@@ -19,11 +19,10 @@
 
 #include "x11input.h"
 
-#include "x11inputdevice.h"
 
-#include <QString>
 #include <QList>
-#include <QX11Info>
+
+#include "private/qtx11extras_p.h"
 
 #include <xorg/wacom-properties.h>
 
