@@ -18,14 +18,17 @@
 #ifndef WACOMTABLETSERVICE_H
 #define WACOMTABLETSERVICE_H
 
-#include <Plasma/Service>
+#include <QtGlobal>
+
+#include <Plasma5Support/Service>
+namespace Plasma = Plasma5Support;
 
 class WacomTabletService : public Plasma::Service
 {
     Q_OBJECT
 public:
     WacomTabletService(const QString &destination,
-                       QObject *parent = 0);
+                       QObject *parent = nullptr);
     ~WacomTabletService() override;
 
 protected:
