@@ -21,7 +21,6 @@
 #include "ui_buttonactionselectorwidget.h"
 
 #include "buttonactionselectiondialog.h"
-#include "buttonshortcut.h"
 
 #include <QIcon>
 
@@ -138,3 +137,5 @@ void ButtonActionSelectorWidget::updateSelectorButton(const ButtonShortcut& shor
         d->ui->actionSelectionButton->setIcon(QIcon::fromTheme(QLatin1String("configure")));
     }
 }
+
+#include "moc_buttonactionselectorwidget.cpp"
