@@ -32,7 +32,6 @@
 
 //KDE includes
 #include <KShortcutsEditor>
-#include <KGlobalAccel>
 
 //Qt includes
 #include <QStringList>
@@ -166,3 +165,5 @@ void GeneralPageWidget::profileRemove()
         emit changed();
     }
 }
+
+#include "moc_generalpagewidget.cpp"
