@@ -22,6 +22,7 @@
 
 // KDE includes
 #include <KCModule>
+#include "kcoreaddons_version.h"
 
 //Qt includes
 #include <QMap>
@@ -49,7 +50,7 @@ public:
       * @param parent parent widget
       * @param args arguments
       */
-    KCMWacomTablet(QWidget *parent, const QVariantList &);
+    KCMWacomTablet(QObject *parent, const KPluginMetaData &md);
     ~KCMWacomTablet() override;
 
     /**
