@@ -1,4 +1,4 @@
-/*
+	/*
  * This file is part of the KDE wacomtablet project. For copyright
  * information and license terms see the AUTHORS and COPYING files
  * in the top-level directory of this distribution.
@@ -45,9 +45,9 @@
 #include <QLineEdit>
 #include <QInputDialog>
 #include <QDialogButtonBox>
-#include <QX11Info>
 #include <QMessageBox>
 #include <QScrollArea>
+#include <kwidgetsaddons_version.h>
 
 using namespace Wacom;
 
@@ -116,13 +116,14 @@ void KCMWacomTabletWidget::setupUi()
     d->ui.delProfileButton->setIcon( QIcon::fromTheme( QLatin1String( "edit-delete-page" ) ) );
 
     // connect tablet selector
-    connect( d->ui.tabletListSelector,  SIGNAL(currentIndexChanged(QString)), SLOT(onTabletSelectionChanged()) );
+    connect( d->ui.tabletListSelector,  QOverload<int>::of(&QComboBox::currentIndexChanged), this, &KCMWacomTabletWidget::onTabletSelectionChanged);
 
     // connect profile selector
     connect( d->ui.addProfileButton, SIGNAL(clicked(bool)), SLOT(addProfile()) );
     connect( d->ui.delProfileButton, SIGNAL(clicked(bool)), SLOT(delProfile()) );
-    connect( d->ui.profileSelector,  SIGNAL(currentIndexChanged(QString)), SLOT(switchProfile(QString)) );
-
+    connect( d->ui.profileSelector,  qOverload<int>(&QComboBox::currentIndexChanged), this, [this, d](int index) {
+        switchProfile(d->ui.profileSelector->itemText(index));
+    });
 
     // connect configuration tabs
     connect( &(d->generalPage), SIGNAL(changed()), SLOT(profileChanged()) );
@@ -166,10 +167,6 @@ void KCMWacomTabletWidget::showHideConfig()
         QString errorMsg   = i18n( "Please start the KDE wacom tablet service to use this configuration dialog.\n"
                                    "The service is required for tablet detection and profile support." );
         showError( errorTitle, errorMsg );
-    } else if(!QX11Info::isPlatformX11()) {
-        QString errorTitle = i18n("Unsupported platform detected");
-        QString errorMsg   = i18n("Currently only X11 is supported.");
-        showError(errorTitle, errorMsg);
     } else if( connectedTablets.value().count() == 0 ) {
         QString errorTitle = i18n( "No tablet device detected" );
         QString errorMsg   = i18n( "Please connect a tablet device to continue.\n"
@@ -475,15 +472,15 @@ void KCMWacomTabletWidget::showSaveChanges()
 
     // TODO: This should be a proper Yes/No/Cancel dialog
     // but this probably requires custom ComboBoxes for canceling selection
-    if (KMessageBox::questionYesNo(this, i18n("Save changes to the current profile?"))
-            == KMessageBox::Yes) {
+    if (KMessageBox::questionTwoActions(this, i18n("Save changes to the current profile?"), i18n("Save Profile"), KStandardGuiItem::save(), KStandardGuiItem::discard())
+            == KMessageBox::ButtonCode::PrimaryAction) {
         saveProfile();
     }
 }
 
 void KCMWacomTabletWidget::showTabletFinder()
 {
-    bool success = QProcess::startDetached(QStringLiteral("kde_wacom_tabletfinder"));
+    const bool success = QProcess::startDetached(QStringLiteral("kde_wacom_tabletfinder"), QStringList());
 
     if (!success) {
         QString err = i18n("Failed to launch Wacom tablet finder tool. Check your installation.");
@@ -507,3 +504,5 @@ void KCMWacomTabletWidget::addTabletToSelector(const QString &tabletId)
 
     d->ui.tabletListSelector->addItem(QString::fromLatin1("%1 [%2]").arg(deviceName).arg(tabletId),tabletId);
 }
+
+#include "moc_kcmwacomtabletwidget.cpp"
