@@ -23,7 +23,6 @@
 #include "tabletareaselectionview.h"
 #include "calibrationdialog.h"
 
-#include "screenmap.h"
 #include "stringutils.h"
 #include "screensinfo.h"
 #include "x11wacom.h"
@@ -358,3 +357,5 @@ void TabletAreaSelectionController::setSelection(const TabletArea &selection)
         d->view->selectPartOfTablet(selection);
     }
 }
+
+#include "moc_tabletareaselectioncontroller.cpp"
