@@ -38,9 +38,12 @@
 #include <KPluginFactory>
 #include <KNotification>
 #include <KLocalizedString>
+#include <KIO/ApplicationLauncherJob>
+
 #include <QGuiApplication>
 #include <QScreen>
-#include <QX11Info>
+
+#include "private/qtx11extras_p.h"
 
 using namespace Wacom;
 
@@ -103,13 +106,25 @@ void TabletDaemon::onNotify(const QString& eventId, const QString& title, const
     notification->setComponentName( QStringLiteral("wacomtablet") );
     notification->setTitle(title);
     notification->setText(message);
-    notification->setIconName( QLatin1String( "input-tablet" ) );
+    notification->setIconName( QLatin1String( "preferences-desktop-tablet" ) );
 
     if (suggestConfigure) {
+#if QT_VERSION_MAJOR == 5
         notification->setActions(QStringList{
                                      i18nc("Button that shows up in notification of a new tablet being connected", "Configure")
                                  });
-        connect(notification, &KNotification::action1Activated, this, &TabletDaemon::onOpenConfiguration);
+        connect(notification, &KNotification::action1Activated, this, [notification]{
+#else
+        KNotificationAction *configureAction =
+            notification->addAction(i18nc("Button that shows up in notification "
+                                          "of a new tablet being connected",
+                                          "Configure"));
+        connect(configureAction, &KNotificationAction::activated, this, [notification] {
+#endif
+            auto *job = new KIO::ApplicationLauncherJob(KService::serviceByDesktopName(QStringLiteral("kcm_wacomtablet")));
+            job->setStartupId(notification->xdgActivationToken().toUtf8());
+            job->start();
+        });
     }
 
     notification->sendEvent();
@@ -129,13 +144,6 @@ void TabletDaemon::onProfileChanged(const QString &tabletId, const QString& prof
     setupActions();
 }
 
-void TabletDaemon::onOpenConfiguration() const
-{
-    QProcess::startDetached(QStringLiteral("kcmshell5 wacomtablet"));
-}
-
-
-
 void TabletDaemon::setupActions()
 {
     Q_D( TabletDaemon );
@@ -162,7 +170,7 @@ void TabletDaemon::setupActions()
 
 void TabletDaemon::setupApplication()
 {
-    static AboutData about(QLatin1Literal("wacomtablet"),
+    static AboutData about(QLatin1String("wacomtablet"),
                            i18n( "Graphic Tablet Configuration daemon"),
                            QLatin1String(WACOMTABLET_VERSION_STRING), i18n( "A Wacom tablet control daemon" ));
 }
@@ -229,12 +237,9 @@ void TabletDaemon::monitorScreenGeometry(QScreen *screen)
         tabletHandler->onScreenRotated(screen->name(), newScreenRotation);
     });
 
-    screen->setOrientationUpdateMask(Qt::LandscapeOrientation |
-                                     Qt::PortraitOrientation |
-                                     Qt::InvertedLandscapeOrientation |
-                                     Qt::InvertedPortraitOrientation);
-
     connect(screen, &QScreen::geometryChanged, &(d->tabletHandler), &TabletHandler::onScreenGeometryChanged);
 }
 
 #include "tabletdaemon.moc"
+
+#include "moc_tabletdaemon.cpp"
