@@ -28,6 +28,8 @@
 #include <QMap>
 #include <QString>
 
+#include "private/qtx11extras_p.h"
+
 using namespace Wacom;
 
 namespace Wacom
@@ -187,3 +189,5 @@ bool TabletFinder::lookupInformation(TabletInformation& info)
     qCWarning(KDED) << QString::fromLatin1("Could not find tablet with id '%1' in database.").arg(info.get (TabletInfo::TabletId));
     return false;
 }
+
+#include "moc_tabletfinder.cpp"
