@@ -60,8 +60,7 @@ protected:
     /**
       * Called by Qt when a new X11 event is detected.
       */
-    bool nativeEventFilter(const QByteArray& eventType, void* message, long int* result) Q_DECL_OVERRIDE;
-
+    bool nativeEventFilter(const QByteArray &eventType, void *message, qintptr *result) override;
 
 private:
     X11EventNotifier();
