@@ -29,9 +29,6 @@
 #include "x11wacom.h"
 
 #include <QApplication>
-#include <QDesktopWidget>
-#include <QProcess>
-#include <QRegExp>
 
 using namespace Wacom;
 
